Add-Type -AssemblyName System.Windows.Forms
Add-Type -AssemblyName System.Drawing
Add-Type -AssemblyName System.Runtime.InteropServices

# DWM Funktionen fr den Glas-Effekt
Add-Type @"
using System;
using System.Runtime.InteropServices;
public class Dwm {
    [DllImport("dwmapi.dll")]
    public static extern int DwmExtendFrameIntoClientArea(IntPtr hWnd, ref MARGINS pMarInset);
    [DllImport("dwmapi.dll")]
    public static extern int DwmIsCompositionEnabled(out bool pfEnabled);

    [StructLayout(LayoutKind.Sequential)]
    public struct MARGINS {
        public int cxLeftWidth;
        public int cxRightWidth;
        public int cyTopHeight;
        public int cyBottomHeight;
    }
}
"@

function Test-Admin {
    $currentIdentity = [Security.Principal.WindowsIdentity]::GetCurrent()
    $principal = New-Object Security.Principal.WindowsPrincipal($currentIdentity)
    return $principal.IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)
}

if (-not (Test-Admin)) {
    $args = "-NoProfile -ExecutionPolicy Bypass -File `"$PSCommandPath`""
    Start-Process PowerShell -ArgumentList $args -Verb RunAs
    exit
}

function Enable-LAN {
    $adapterName = "Ethernet"
    $adapter = Get-NetAdapter -Name $adapterName -ErrorAction SilentlyContinue

    if ($null -ne $adapter) {
        Enable-NetAdapter -Name $adapterName -Confirm:$false
        [System.Windows.Forms.MessageBox]::Show("Die LAN-Verbindung '$adapterName' wurde aktiviert.", "Erfolg")
    } else {
        [System.Windows.Forms.MessageBox]::Show("Der LAN-Adapter '$adapterName' wurde nicht gefunden.", "Fehler")
    }
}

function Disable-LAN {
    $adapterName = "Ethernet"
    $adapter = Get-NetAdapter -Name $adapterName -ErrorAction SilentlyContinue

    if ($null -ne $adapter) {
        Disable-NetAdapter -Name $adapterName -Confirm:$false
        [System.Windows.Forms.MessageBox]::Show("Die LAN-Verbindung '$adapterName' wurde deaktiviert.", "Erfolg")
    } else {
        [System.Windows.Forms.MessageBox]::Show("Der LAN-Adapter '$adapterName' wurde nicht gefunden.", "Fehler")
    }
}

function Open-AdapterSettings {
    Start-Process "ms-settings:network-ethernet"
}

$form = New-Object System.Windows.Forms.Form
$form.Text = "LAN-Verwaltung"
$form.Size = New-Object System.Drawing.Size(300, 250)
$form.StartPosition = "CenterScreen"

# DWM aktivieren und Glas-Effekt hinzufgen
$mar = New-Object Dwm+MARGINS
$mar.cxLeftWidth = -1
$mar.cxRightWidth = -1
$mar.cyTopHeight = -1
$mar.cyBottomHeight = -1
[Dwm]::DwmExtendFrameIntoClientArea($form.Handle, [ref]$mar)

$form.BackColor = [System.Drawing.Color]::FromArgb(240, 240, 240)

# Normale Schriftart
$normalFont = New-Object System.Drawing.Font("Segoe UI", 10, [System.Drawing.FontStyle]::Regular)

$enableButton = New-Object System.Windows.Forms.Button
$enableButton.Location = New-Object System.Drawing.Point(50, 30)
$enableButton.Size = New-Object System.Drawing.Size(200, 40)
$enableButton.Text = "LAN-Verbindung aktivieren"
$enableButton.BackColor = [System.Drawing.Color]::FromArgb(144, 238, 144)
$enableButton.ForeColor = [System.Drawing.Color]::Black
$enableButton.FlatStyle = [System.Windows.Forms.FlatStyle]::Flat
$enableButton.Font = $normalFont
$enableButton.Add_Click({ Enable-LAN })
$form.Controls.Add($enableButton)

$disableButton = New-Object System.Windows.Forms.Button
$disableButton.Location = New-Object System.Drawing.Point(50, 80)
$disableButton.Size = New-Object System.Drawing.Size(200, 40)
$disableButton.Text = "LAN-Verbindung deaktivieren"
$disableButton.BackColor = [System.Drawing.Color]::FromArgb(255, 182, 193)
$disableButton.ForeColor = [System.Drawing.Color]::Black
$disableButton.FlatStyle = [System.Windows.Forms.FlatStyle]::Flat
$disableButton.Font = $normalFont
$disableButton.Add_Click({ Disable-LAN })
$form.Controls.Add($disableButton)

$settingsButton = New-Object System.Windows.Forms.Button
$settingsButton.Location = New-Object System.Drawing.Point(50, 130)
$settingsButton.Size = New-Object System.Drawing.Size(200, 40)
$settingsButton.Text = "Netzwerkeinstellungen ffnen"
$settingsButton.BackColor = [System.Drawing.Color]::FromArgb(173, 216, 230)
$settingsButton.ForeColor = [System.Drawing.Color]::Black
$settingsButton.FlatStyle = [System.Windows.Forms.FlatStyle]::Flat
$settingsButton.Font = $normalFont
$settingsButton.Add_Click({ Open-AdapterSettings })
$form.Controls.Add($settingsButton)

$form.Add_Shown({$form.Activate()})
[void]$form.ShowDialog()